pub enum Value {
Show 30 variants
Null,
Boolean(Option<bool>),
Int8(Option<i8>),
Int16(Option<i16>),
Int32(Option<i32>),
Int64(Option<i64>),
Int128(Option<i128>),
UInt8(Option<u8>),
UInt16(Option<u16>),
UInt32(Option<u32>),
UInt64(Option<u64>),
UInt128(Option<u128>),
Float32(Option<f32>),
Float64(Option<f64>),
Decimal(Option<Decimal>, u8, u8),
Char(Option<char>),
Varchar(Option<Cow<'static, str>>),
Blob(Option<Box<[u8]>>),
Date(Option<Date>),
Time(Option<Time>),
Timestamp(Option<PrimitiveDateTime>),
TimestampWithTimezone(Option<OffsetDateTime>),
Interval(Option<Interval>),
Uuid(Option<Uuid>),
Array(Option<Box<[Value]>>, Box<Value>, u32),
List(Option<Vec<Value>>, Box<Value>),
Map(Option<HashMap<Value, Value>>, Box<Value>, Box<Value>),
Json(Option<Value>),
Struct(Option<Vec<(String, Value)>>, Vec<(String, Value)>, TableRef),
Unknown(Option<String>),
}Expand description
SQL value representation.
Variants correspond to database column types.
Variants
Null
SQL NULL.
Boolean(Option<bool>)
Boolean value.
Int8(Option<i8>)
8-bit signed integer.
Int16(Option<i16>)
16-bit signed integer.
Int32(Option<i32>)
32-bit signed integer.
Int64(Option<i64>)
64-bit signed integer.
Int128(Option<i128>)
128-bit signed integer.
UInt8(Option<u8>)
8-bit unsigned integer.
UInt16(Option<u16>)
16-bit unsigned integer.
UInt32(Option<u32>)
32-bit unsigned integer.
UInt64(Option<u64>)
64-bit unsigned integer.
UInt128(Option<u128>)
128-bit unsigned integer.
Float32(Option<f32>)
32-bit floating point number.
Float64(Option<f64>)
64-bit floating point number.
Decimal(Option<Decimal>, u8, u8)
Decimal (value, precision, scale).
Char(Option<char>)
Single character.
Varchar(Option<Cow<'static, str>>)
Variable-length character string.
Blob(Option<Box<[u8]>>)
Binary large object.
Date(Option<Date>)
Date value (without time).
Time(Option<Time>)
Time value (without date).
Timestamp(Option<PrimitiveDateTime>)
Timestamp (date and time).
TimestampWithTimezone(Option<OffsetDateTime>)
Timestamp with time zone.
Interval(Option<Interval>)
Time interval.
Uuid(Option<Uuid>)
UUID (Universally Unique Identifier).
Array(Option<Box<[Value]>>, Box<Value>, u32)
Homogeneous array (values, inner type, length).
List(Option<Vec<Value>>, Box<Value>)
Variable-length list (values, inner type).
Map(Option<HashMap<Value, Value>>, Box<Value>, Box<Value>)
Map (entries, key type, value type).
Json(Option<Value>)
JSON value.
Struct(Option<Vec<(String, Value)>>, Vec<(String, Value)>, TableRef)
Named struct (fields, field types, type name).
Unknown(Option<String>)
Unknown type (usually used when no further information is available).
Implementations
Sourceimpl Value
impl Value
Sourcepub fn same_type(&self, other: &Self) -> bool
pub fn same_type(&self, other: &Self) -> bool
Checks if two values have the same type, ignoring their actual data.
Sourcepub fn as_null(&self) -> Value
pub fn as_null(&self) -> Value
Create a value retaining only the type information, with all data set to NULL.