pub struct FixedDecimal<const WIDTH: u8, const SCALE: u8>(pub Decimal);Expand description
Decimal wrapper enforcing static precision/scale.
WIDTH = total digits, SCALE = fractional digits.
Tuple Fields
0: DecimalTrait Implementations
Sourceimpl<const WIDTH: u8, const SCALE: u8> Clone for FixedDecimal<WIDTH, SCALE>
impl<const WIDTH: u8, const SCALE: u8> Clone for FixedDecimal<WIDTH, SCALE>
Sourcefn clone(&self) -> FixedDecimal<WIDTH, SCALE>
fn clone(&self) -> FixedDecimal<WIDTH, SCALE>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<const WIDTH: u8, const SCALE: u8> Copy for FixedDecimal<WIDTH, SCALE>
Sourceimpl<const WIDTH: u8, const SCALE: u8> Default for FixedDecimal<WIDTH, SCALE>
impl<const WIDTH: u8, const SCALE: u8> Default for FixedDecimal<WIDTH, SCALE>
Sourcefn default() -> FixedDecimal<WIDTH, SCALE>
fn default() -> FixedDecimal<WIDTH, SCALE>
Returns the “default value” for a type. Read more
impl<const WIDTH: u8, const SCALE: u8> Eq for FixedDecimal<WIDTH, SCALE>
Sourceimpl<const W: u8, const S: u8> Expression for FixedDecimal<W, S>
impl<const W: u8, const S: u8> Expression for FixedDecimal<W, S>
Sourcefn write_query(
&self,
writer: &dyn SqlWriter,
context: &mut Context,
out: &mut DynQuery,
)
fn write_query( &self, writer: &dyn SqlWriter, context: &mut Context, out: &mut DynQuery, )
Generates the SQL representation of this expression.
Sourcefn accept_visitor(
&self,
_matcher: &mut dyn ExpressionVisitor,
_writer: &dyn SqlWriter,
_context: &mut Context,
_out: &mut DynQuery,
) -> bool
fn accept_visitor( &self, _matcher: &mut dyn ExpressionVisitor, _writer: &dyn SqlWriter, _context: &mut Context, _out: &mut DynQuery, ) -> bool
Traverses the expression with a visitor. Read more
Sourcefn as_identifier(&self, context: &mut Context) -> String
fn as_identifier(&self, context: &mut Context) -> String
Renders the expression as a string suitable for use as an identifier.
Sourceimpl<const W: u8, const S: u8> From<FixedDecimal<W, S>> for Decimal
impl<const W: u8, const S: u8> From<FixedDecimal<W, S>> for Decimal
Sourcefn from(value: FixedDecimal<W, S>) -> Self
fn from(value: FixedDecimal<W, S>) -> Self
Converts to this type from the input type.
Sourceimpl<const W: u8, const S: u8> OpPrecedence for FixedDecimal<W, S>
impl<const W: u8, const S: u8> OpPrecedence for FixedDecimal<W, S>
Sourcefn precedence(&self, _: &dyn SqlWriter) -> i32
fn precedence(&self, _: &dyn SqlWriter) -> i32
Lower numbers bind weaker, writers parenthesize when child precedence <= operator precedence.
Sourceimpl<const WIDTH: u8, const SCALE: u8> Ord for FixedDecimal<WIDTH, SCALE>
impl<const WIDTH: u8, const SCALE: u8> Ord for FixedDecimal<WIDTH, SCALE>
Sourcefn cmp(&self, other: &FixedDecimal<WIDTH, SCALE>) -> Ordering
fn cmp(&self, other: &FixedDecimal<WIDTH, SCALE>) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<const WIDTH: u8, const SCALE: u8> PartialEq for FixedDecimal<WIDTH, SCALE>
impl<const WIDTH: u8, const SCALE: u8> PartialEq for FixedDecimal<WIDTH, SCALE>
Sourcefn eq(&self, other: &FixedDecimal<WIDTH, SCALE>) -> bool
fn eq(&self, other: &FixedDecimal<WIDTH, SCALE>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<const WIDTH: u8, const SCALE: u8> PartialOrd for FixedDecimal<WIDTH, SCALE>
impl<const WIDTH: u8, const SCALE: u8> PartialOrd for FixedDecimal<WIDTH, SCALE>
impl<const WIDTH: u8, const SCALE: u8> StructuralPartialEq for FixedDecimal<WIDTH, SCALE>