Dataset

Trait Dataset 

pub trait Dataset {
    // Required methods
    fn qualified_columns() -> bool
       where Self: Sized;
    fn write_query(
        &self,
        writer: &dyn SqlWriter,
        context: &mut Context,
        out: &mut DynQuery,
    );
    fn table_ref(&self) -> TableRef;
}
Queryable data source (table or join tree).

Implementors know how to render themselves inside a FROM clause.

Required Methods

fn qualified_columns() -> bool
where Self: Sized,

Should columns be qualified (schema.table.col)?

fn write_query( &self, writer: &dyn SqlWriter, context: &mut Context, out: &mut DynQuery, )

Generates the SQL representation of this dataset for use in a query.

fn table_ref(&self) -> TableRef

Returns the primary table reference for this dataset.