pub struct PooledConnection<D: Driver> { /* private fields */ }Trait Implementations
Sourceimpl<D: Driver> AsMut<<D as Driver>::Connection> for PooledConnection<D>
impl<D: Driver> AsMut<<D as Driver>::Connection> for PooledConnection<D>
Sourcefn as_mut(&mut self) -> &mut D::Connection
fn as_mut(&mut self) -> &mut D::Connection
Converts this type into a mutable reference of the (usually inferred) input type.
Sourceimpl<D: Driver> AsRef<<D as Driver>::Connection> for PooledConnection<D>
impl<D: Driver> AsRef<<D as Driver>::Connection> for PooledConnection<D>
Sourcefn as_ref(&self) -> &D::Connection
fn as_ref(&self) -> &D::Connection
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl<D: Driver> Connection for PooledConnection<D>
impl<D: Driver> Connection for PooledConnection<D>
Sourcefn connect(
_driver: &D,
_url: Cow<'static, str>,
) -> impl Future<Output = Result<<D as Driver>::Connection>> + Sendwhere
Self: Sized,
fn connect(
_driver: &D,
_url: Cow<'static, str>,
) -> impl Future<Output = Result<<D as Driver>::Connection>> + Sendwhere
Self: Sized,
Establishes a connection (or pool) to the database specified by the URL. Read more
Sourcefn begin(
&mut self,
) -> impl Future<Output = Result<<D as Driver>::Transaction<'_>>> + Send
fn begin( &mut self, ) -> impl Future<Output = Result<<D as Driver>::Transaction<'_>>> + Send
Starts a new transaction on this connection. Read more
Sourceimpl<D: Driver> Deref for PooledConnection<D>
impl<D: Driver> Deref for PooledConnection<D>
Sourceimpl<D: Driver> DerefMut for PooledConnection<D>
impl<D: Driver> DerefMut for PooledConnection<D>
Sourceimpl<D: Driver> Executor for PooledConnection<D>
impl<D: Driver> Executor for PooledConnection<D>
Sourcefn accepts_multiple_statements(&self) -> bool
fn accepts_multiple_statements(&self) -> bool
Checks if the driver supports multiple SQL statements in a single request.
Sourcefn prepare<'s>(
&'s mut self,
query: impl AsQuery<D> + 's,
) -> impl Future<Output = Result<Query<D>>> + Send
fn prepare<'s>( &'s mut self, query: impl AsQuery<D> + 's, ) -> impl Future<Output = Result<Query<D>>> + Send
Prepares a query for execution, returning a handle to the prepared statement.
Sourcefn do_prepare(
&mut self,
sql: String,
) -> impl Future<Output = Result<Query<D>>> + Send
fn do_prepare( &mut self, sql: String, ) -> impl Future<Output = Result<Query<D>>> + Send
Internal hook for implementing prepared statement support.
Sourcefn run<'s>(
&'s mut self,
query: impl AsQuery<D> + 's,
) -> impl Stream<Item = Result<QueryResult>> + Send
fn run<'s>( &'s mut self, query: impl AsQuery<D> + 's, ) -> impl Stream<Item = Result<QueryResult>> + Send
Executes a query and streams the results (rows or affected counts).
Sourcefn fetch<'s>(
&'s mut self,
query: impl AsQuery<D> + 's,
) -> impl Stream<Item = Result<Row>> + Send
fn fetch<'s>( &'s mut self, query: impl AsQuery<D> + 's, ) -> impl Stream<Item = Result<Row>> + Send
Executes a query and streams the resulting rows, ignoring affected counts.
Sourcefn execute<'s>(
&'s mut self,
query: impl AsQuery<D> + 's,
) -> impl Future<Output = Result<RowsAffected>> + Send
fn execute<'s>( &'s mut self, query: impl AsQuery<D> + 's, ) -> impl Future<Output = Result<RowsAffected>> + Send
Executes a query and returns the total number of affected rows.